DioGateway<T extends Object> class

DioGateway wraps Dio calls. It can only fetch and map the response, also providing abilities to Dio features like callbacks for the onSendProgress and onReceiveProgress.

mapper is used to map the responses to the T. options are passed to every Dio request.

Implemented types

Constructors

DioGateway({required Dio dio, RequestMapper<Response, T>? mapper, void onReceiveProgress(int, int)?, void onSendProgress(int, int)?, Options? options})

Properties

dio → Dio
final
hashCode int
The hash code for this object.
no setterinherited
mapper RequestMapper<Response, T>?
final
onReceiveProgress → void Function(int, int)?
final
onSendProgress → void Function(int, int)?
final
options → Options?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
fetch(Request request) Future<T>
override
init() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited